@@ -171,6 +171,7 @@ key_press_event(GtkWidget *widget, GdkEventKey *event, gpointer data)
 {
   charpick_data *p_curr_data = data;
   gchar inputchar = event->keyval;
+
   switch (inputchar)
     {
     case 'a' : p_curr_data->charlist = a_list;
@@ -287,7 +288,7 @@ build_table(charpick_data *p_curr_data)
     currstr[0] = p_curr_data->charlist[i];
     currstr[1] = '\0';
  
-    str_utf8 = g_locale_to_utf8 (currstr, -1, NULL, NULL, NULL);
+    str_utf8 = g_convert (currstr, -1, "UTF-8", "ISO-8859-1", NULL, NULL, NULL);
     toggle_button = gtk_toggle_button_new_with_label (str_utf8);
     g_free (str_utf8);
     gtk_box_pack_start (GTK_BOX (box), toggle_button, TRUE, TRUE, 0);
@@ -391,22 +392,12 @@ static const BonoboUIVerb charpick_applet_menu_verbs [] = {
         BONOBO_UI_VERB_END
 };
 
-static const char charpick_applet_menu_xml [] =
-	"<popup name=\"button3\">\n"
-	"   <menuitem name=\"Item 1\" verb=\"Props\" _label=\"Properties\"\n"
-	"             pixtype=\"stock\" pixname=\"gtk-properties\"/>\n"
-	"   <menuitem name=\"Item 2\" verb=\"Help\" _label=\"Help\"\n"
-	"             pixtype=\"stock\" pixname=\"gtk-help\"/>\n"
-	"   <menuitem name=\"Item 3\" verb=\"About\" _label=\"About\"\n"
-	"             pixtype=\"stock\" pixname=\"gnome-stock-about\"/>\n"
-	"</popup>\n";
-
-
 static gboolean
 charpicker_applet_fill (PanelApplet *applet)
 {
   charpick_data *curr_data;
   GtkWidget *event_box = NULL;
+  gchar *default_charlist_utf8;
   
   panel_applet_add_preferences (applet, "/schemas/apps/charpick/prefs", NULL);
    
@@ -416,10 +407,16 @@ charpicker_applet_fill (PanelApplet *applet)
   curr_data->event_box = event_box;
   curr_data->applet = GTK_WIDGET (applet);
   
-  curr_data->default_charlist = panel_applet_gconf_get_string (applet, 
-  							       "default_list", NULL);
-  if (!curr_data->default_charlist)
+  default_charlist_utf8 = panel_applet_gconf_get_string (applet, 
+  							 "default_list", NULL);
+  if (!default_charlist_utf8)
     curr_data->default_charlist = g_strdup (def_list);
+  else {
+    curr_data->default_charlist = g_convert (default_charlist_utf8, -1, 
+    					     "ISO-8859-1", "UTF-8", 
+  					      NULL, NULL, NULL);
+    g_free (default_charlist_utf8);
+  }
     
   curr_data->charlist = curr_data->default_charlist;
 
@@ -428,6 +425,7 @@ charpicker_applet_fill (PanelApplet *applet)
   event_box = gtk_event_box_new ();
   curr_data->event_box = event_box; 
   GTK_WIDGET_SET_FLAGS (event_box, GTK_CAN_FOCUS);
+  gtk_widget_set_events (curr_data->event_box, GDK_FOCUS_CHANGE_MASK|GDK_KEY_PRESS_MASK);
 
   /* Create table */
   curr_data->frame = gtk_frame_new (NULL);
@@ -437,7 +435,7 @@ charpicker_applet_fill (PanelApplet *applet)
   gtk_frame_set_shadow_type (GTK_FRAME(curr_data->frame), GTK_SHADOW_IN);
 
   /* Event signals */
-  gtk_signal_connect (GTK_OBJECT (event_box), "key_press_event",
+  gtk_signal_connect (GTK_OBJECT (curr_data->applet), "key_press_event",
 		      (GtkSignalFunc) key_press_event, curr_data);
   /*
   gtk_signal_connect (GTK_OBJECT (applet), "focus_in_event",
@@ -447,8 +445,6 @@ charpicker_applet_fill (PanelApplet *applet)
 		      (GtkSignalFunc) focus_out_event, NULL);
   */
 
-  gtk_widget_set_events (curr_data->event_box, GDK_FOCUS_CHANGE_MASK|GDK_KEY_PRESS_MASK);
-
   /* selection handling for selected character */
   gtk_selection_add_target (curr_data->event_box, 
 			    GDK_SELECTION_PRIMARY,
@@ -473,10 +469,12 @@ charpicker_applet_fill (PanelApplet *applet)
   
   gtk_widget_show_all (GTK_WIDGET (applet));
   
-  panel_applet_setup_menu (PANEL_APPLET (applet),
-			   charpick_applet_menu_xml,
-			   charpick_applet_menu_verbs,
-			   curr_data);
+  panel_applet_setup_menu_from_file (PANEL_APPLET (applet),
+                                     NULL,
+			             "GNOME_CharpickerApplet.xml",
+                                     NULL,
+			             charpick_applet_menu_verbs,
+			             curr_data);
 
   return TRUE;
 }
