@@ -1,4 +1,4 @@
-/* $Id: gweather-applet.c,v 1.31 2002/01/26 00:38:10 kevinv Exp $ */
+/* $Id: gweather-applet.c,v 1.35 2002/02/17 15:54:45 kmaraas Exp $ */
 
 /*
  *  Papadimitriou Spiros <spapadim+@cs.cmu.edu>
@@ -155,25 +155,12 @@ static const BonoboUIVerb weather_applet_menu_verbs [] = {
 	BONOBO_UI_VERB ("Forecast", forecast_cb),
 	BONOBO_UI_VERB ("Update", update_cb),
         BONOBO_UI_VERB ("Props", pref_cb),
-        BONOBO_UI_VERB ("Help", help_cb),
+/*        BONOBO_UI_VERB ("Help", help_cb), */
         BONOBO_UI_VERB ("About", about_cb),
 
         BONOBO_UI_VERB_END
 };
 
-static const char weather_applet_menu_xml [] =
-	"<popup name=\"button3\">\n"
-	"   <menuitem name=\"Item 1\" verb=\"Forecast\" _label=\"Forecast\"/>\n"
-	"   <menuitem name=\"Item 2\" verb=\"Update\" _label=\"Update\"\n"
-	"             pixtype=\"stock\" pixname=\"gtk-refresh\"/>\n"
-	"   <menuitem name=\"Item 3\" verb=\"Props\" _label=\"Properties\"\n"
-	"             pixtype=\"stock\" pixname=\"gtk-properties\"/>\n"
-	"   <menuitem name=\"Item 4\" verb=\"Help\" _label=\"Help\"\n"
-	"             pixtype=\"stock\" pixname=\"gtk-help\"/>\n"
-	"   <menuitem name=\"Item 5\" verb=\"About\" _label=\"About\"\n"
-	"             pixtype=\"stock\" pixname=\"gnome-stock-about\"/>\n"
-	"</popup>\n";
-	
 void gweather_applet_create (GWeatherApplet *gw_applet)
 {
 	GtkWidget *frame;
@@ -197,7 +184,6 @@ void gweather_applet_create (GWeatherApplet *gw_applet)
     gnome_window_icon_set_default_from_file (GNOME_ICONDIR"/gweather/tstorm.xpm");
 
     /* PUSH */
-    gtk_widget_push_visual (gdk_rgb_get_visual ());
     gtk_widget_push_colormap (gdk_rgb_get_cmap ());
 
     /*gtk_widget_realize(GTK_WIDGET(gw_applet->applet));
@@ -246,10 +232,12 @@ void gweather_applet_create (GWeatherApplet *gw_applet)
 
     gw_applet->orient = panel_applet_get_orient (gw_applet->applet);
     
-    panel_applet_setup_menu (gw_applet->applet,
-			     weather_applet_menu_xml,
-			     weather_applet_menu_verbs,
-			     gw_applet);
+    panel_applet_setup_menu_from_file (gw_applet->applet,
+                                       NULL,
+			               "GNOME_GWeatherApplet.xml",
+                                       NULL,
+			               weather_applet_menu_verbs,
+			               gw_applet);
 
 	gw_applet->frame = frame;
 	gw_applet->label = label;
@@ -262,7 +250,6 @@ void gweather_applet_create (GWeatherApplet *gw_applet)
     place_widgets(gw_applet);
     /* POP */
     gtk_widget_pop_colormap ();
-    gtk_widget_pop_visual ();
     
 	return;
 }
@@ -299,7 +286,7 @@ void gweather_info_load (const gchar *path, GWeatherApplet *gw_applet)
     g_free(prefix);
 
     weather_info_free (gw_applet->gweather_info);
-    gw_applet->gweather_info = weather_info_config_read();
+    gw_applet->gweather_info = weather_info_config_read(gw_applet->applet);
 
     gnome_config_pop_prefix();
 }
@@ -356,7 +343,7 @@ static void update_finish (WeatherInfo *info)
         gtk_timeout_remove(gw_applet->timeout_tag);
     if (gw_applet->gweather_pref.update_enabled)
         gw_applet->timeout_tag =  gtk_timeout_add (gw_applet->gweather_pref.update_interval * 1000,
-                                        timeout_cb, NULL);
+                                        timeout_cb, gw_applet);
 
     /* Update dialog -- if one is present */
     gweather_dialog_update(gw_applet);
