@@ -1,7 +1,7 @@
 #ifndef __WEATHER_H_
 #define __WEATHER_H_
 
-/* $Id: weather.h,v 1.6 2000/11/30 23:24:22 alan Exp $ */
+/* $Id: weather.h,v 1.11 2002/02/10 17:20:36 kevinv Exp $ */
 
 /*
  *  Papadimitriou Spiros <spapadim+@cs.cmu.edu>
@@ -14,11 +14,16 @@
  */
 
 #include <time.h>
+#include <panel-applet.h>
+#include <panel-applet-gconf.h>
+#include <libgnomevfs/gnome-vfs.h>
 
 /*
  * Location
  */
 
+G_BEGIN_DECLS
+
 #define WEATHER_LOCATION_NAME_MAX_LEN 100
 #define WEATHER_LOCATION_CODE_LEN     4
 #define WEATHER_LOCATION_ZONE_LEN     7
@@ -39,7 +44,7 @@ extern void weather_location_free (WeatherLocation *location);
 extern gboolean weather_location_equal (const WeatherLocation *location1, const WeatherLocation *location2);
 
 extern void weather_location_config_write (gchar *prefix, WeatherLocation *location);
-extern WeatherLocation *weather_location_config_read (gchar *prefix);
+extern WeatherLocation *weather_location_config_read (PanelApplet *applet);
 
 
 /*
@@ -51,7 +56,7 @@ enum _WeatherWindDirection {
     WIND_N, WIND_NNE, WIND_NE, WIND_ENE,
     WIND_E, WIND_ESE, WIND_SE, WIND_SSE,
     WIND_S, WIND_SSW, WIND_SW, WIND_WSW,
-    WIND_W, WIND_WNW, WIND_NW, WIND_NNW,
+    WIND_W, WIND_WNW, WIND_NW, WIND_NNW
 };
 
 typedef enum _WeatherWindDirection WeatherWindDirection;
@@ -180,7 +185,16 @@ struct _WeatherInfo {
     WeatherPressure pressure;
     WeatherVisibility visibility;
     gchar *forecast;
+    gchar *metar_buffer;
+    gchar *iwin_buffer;
+    gchar *met_buffer;
+    gchar *radar_buffer;
     GdkPixmap *radar;
+    GnomeVFSAsyncHandle *metar_handle;
+    GnomeVFSAsyncHandle *iwin_handle;
+    GnomeVFSAsyncHandle *wx_handle;
+    GnomeVFSAsyncHandle *met_handle;
+    gboolean requests_pending;
 };
 
 typedef struct _WeatherInfo WeatherInfo;
@@ -194,7 +208,7 @@ extern WeatherInfo *weather_info_clone (const WeatherInfo *info);
 extern void weather_info_free (WeatherInfo *info);
 
 extern void weather_info_config_write (WeatherInfo *info);
-extern WeatherInfo *weather_info_config_read (void);
+extern WeatherInfo *weather_info_config_read (PanelApplet *applet);
 
 extern void weather_info_to_metric (WeatherInfo *info);
 extern void weather_info_to_imperial (WeatherInfo *info);
@@ -221,6 +235,7 @@ extern void _weather_info_get_pixmap (WeatherInfo *info, gboolean mini, GdkPixma
 #define weather_info_get_pixmap_mini(info,pixmap,mask) _weather_info_get_pixmap((info), TRUE, (pixmap), (mask))
 #define weather_info_get_pixmap(info,pixmap,mask) _weather_info_get_pixmap((info), FALSE, (pixmap), (mask))
 
+G_END_DECLS
 
 #endif /* __WEATHER_H_ */
 
