@@ -32,15 +32,6 @@
 
 static void reset_temporary_prefs(void);
 
-properties prop;
-properties prop_tmp;
-
-static void
-checkbox_toggled_signal(GtkWidget *check_box_widget, int *data)
-{
-    *data = GTK_TOGGLE_BUTTON(check_box_widget)->active;
-}
-
 static void
 entry_changed_signal(GtkWidget *entry_widget, char **data)
 {
@@ -56,63 +47,46 @@ entry_integer_changed_signal(GtkWidget *entry_widget, int *data)
 }
 
 static void
-color_cmd_fg_changed_signal(GtkWidget *color_picker_widget, gpointer *data)
+color_cmd_fg_changed_signal(GtkWidget *color_picker_widget,
+                            guint r, guint b, guint g, guint a, gpointer data)
 {
-    gushort r, g, b;
-
-    gnome_color_picker_get_i16(GNOME_COLOR_PICKER(color_picker_widget), &r, &g, &b, NULL);
-
-    prop_tmp.cmd_line_color_fg_r = (int) r;
-    prop_tmp.cmd_line_color_fg_g = (int) g; 
-    prop_tmp.cmd_line_color_fg_b = (int) b;
+    PanelApplet *applet = data;
+    properties *prop;
+    
+    prop = g_object_get_data (G_OBJECT (applet), "prop");
+    
+    prop->cmd_line_color_fg_r = (int) r;
+    prop->cmd_line_color_fg_g = (int) g; 
+    prop->cmd_line_color_fg_b = (int) b;
+    
+    command_entry_update_color (prop);
     return;
     data = NULL;
 }
 
 static void
-color_cmd_bg_changed_signal(GtkWidget *color_picker_widget, gpointer *data)
+color_cmd_bg_changed_signal(GtkWidget *color_picker_widget, 
+			    guint r, guint b, guint g, guint a, gpointer data)
 {
-    gushort r, g, b;
-
-    gnome_color_picker_get_i16(GNOME_COLOR_PICKER(color_picker_widget), &r, &g, &b, NULL);
-
-    prop_tmp.cmd_line_color_bg_r = (int) r;
-    prop_tmp.cmd_line_color_bg_g = (int) g; 
-    prop_tmp.cmd_line_color_bg_b = (int) b;
+    PanelApplet *applet = data;
+    properties *prop;
+    
+    prop = g_object_get_data (G_OBJECT (applet), "prop");
+    
+    prop->cmd_line_color_bg_r = (int) r;
+    prop->cmd_line_color_bg_g = (int) g; 
+    prop->cmd_line_color_bg_b = (int) b;
+    
+    command_entry_update_color (prop);
     return;
     data = NULL;
 }
 
-static void
-reset_temporary_prefs(void)
-{
-    /* reset temporary prefereces */
-    prop_tmp.show_time = -1;
-    prop_tmp.show_date = -1;
-    prop_tmp.show_handle = -1;
-    prop_tmp.show_frame = -1;
-    prop_tmp.auto_complete_history = -1;
-    prop_tmp.normal_size_x = -1;
-    prop_tmp.normal_size_y = -1;
-    prop_tmp.reduced_size_x = -1;
-    prop_tmp.reduced_size_y = -1;
-    prop_tmp.auto_complete_history = -1;
-    prop_tmp.cmd_line_size_y = -1;
-    prop_tmp.flat_layout = -1;
-    prop_tmp.cmd_line_color_fg_r = -1;
-    prop_tmp.cmd_line_color_fg_g = -1;
-    prop_tmp.cmd_line_color_fg_b = -1;
-    prop_tmp.cmd_line_color_bg_r = -1;
-    prop_tmp.cmd_line_color_bg_g = -1;
-    prop_tmp.cmd_line_color_bg_b = -1;
-}
-
-
 static void
 properties_box_apply_signal(GnomePropertyBox *property_box_widget, gint page, gpointer data)
 {
     int i;
-
+#if 0
     if(prop_tmp.show_time != -1)
 	/* checkbox has been changed */
 	prop.show_time = prop_tmp.show_time;
@@ -225,43 +199,47 @@ properties_box_apply_signal(GnomePropertyBox *property_box_widget, gint page, gp
     property_box_widget = NULL;
     page = 0;
     data = NULL;
+#endif
 }
 
 /* FIXME: port to gconf */
-void
+properties *
 load_session(void)
 {
+    properties *prop;
     int i;
     char section[MAX_COMMAND_LENGTH + 100];
     char default_macro_pattern[MAX_MACRO_PATTERN_LENGTH];
     char default_macro_command[MAX_COMMAND_LENGTH];
     
+    prop = g_new0 (properties, 1);
+    
     /* read properties */
     /* gnome_config_push_prefix(APPLET_WIDGET(applet)->globcfgpath); */
     gnome_config_push_prefix("/mini-commander/");
 
-    prop.show_time = gnome_config_get_bool("mini_commander/show_time=true");
-    prop.show_date = gnome_config_get_bool("mini_commander/show_date=false");
-    prop.show_handle = gnome_config_get_bool("mini_commander/show_handle=false");
-    prop.show_frame = gnome_config_get_bool("mini_commander/show_frame=false");
+    prop->show_time = gnome_config_get_bool("mini_commander/show_time=true");
+    prop->show_date = gnome_config_get_bool("mini_commander/show_date=false");
+    prop->show_handle = gnome_config_get_bool("mini_commander/show_handle=false");
+    prop->show_frame = gnome_config_get_bool("mini_commander/show_frame=false");
 
-    prop.auto_complete_history = gnome_config_get_bool("mini_commander/autocomplete_history=true");
+    prop->auto_complete_history = gnome_config_get_bool("mini_commander/autocomplete_history=true");
 
     /* size */
-    prop.normal_size_x = gnome_config_get_int("mini_commander/normal_size_x=148");
-    prop.normal_size_y = gnome_config_get_int("mini_commander/normal_size_y=48");
-    prop.reduced_size_x = gnome_config_get_int("mini_commander/reduced_size_x=50");
-    prop.reduced_size_y = gnome_config_get_int("mini_commander/reduced_size_y=48");
-    prop.cmd_line_size_y = gnome_config_get_int("mini_commander/cmd_line_y=24");
+    prop->normal_size_x = gnome_config_get_int("mini_commander/normal_size_x=148");
+    prop->normal_size_y = gnome_config_get_int("mini_commander/normal_size_y=48");
+    prop->reduced_size_x = gnome_config_get_int("mini_commander/reduced_size_x=50");
+    prop->reduced_size_y = gnome_config_get_int("mini_commander/reduced_size_y=48");
+    prop->cmd_line_size_y = gnome_config_get_int("mini_commander/cmd_line_y=24");
 
     /* colors */
-    prop.cmd_line_color_fg_r = gnome_config_get_int("mini_commander/cmd_line_color_fg_r=64613");
-    prop.cmd_line_color_fg_g = gnome_config_get_int("mini_commander/cmd_line_color_fg_g=64613");
-    prop.cmd_line_color_fg_b = gnome_config_get_int("mini_commander/cmd_line_color_fg_b=64613");
+    prop->cmd_line_color_fg_r = gnome_config_get_int("mini_commander/cmd_line_color_fg_r=64613");
+    prop->cmd_line_color_fg_g = gnome_config_get_int("mini_commander/cmd_line_color_fg_g=64613");
+    prop->cmd_line_color_fg_b = gnome_config_get_int("mini_commander/cmd_line_color_fg_b=64613");
 
-    prop.cmd_line_color_bg_r = gnome_config_get_int("mini_commander/cmd_line_color_bg_r=0");
-    prop.cmd_line_color_bg_g = gnome_config_get_int("mini_commander/cmd_line_color_bg_g=0");
-    prop.cmd_line_color_bg_b = gnome_config_get_int("mini_commander/cmd_line_color_bg_b=0");
+    prop->cmd_line_color_bg_r = gnome_config_get_int("mini_commander/cmd_line_color_bg_r=0");
+    prop->cmd_line_color_bg_g = gnome_config_get_int("mini_commander/cmd_line_color_bg_g=0");
+    prop->cmd_line_color_bg_b = gnome_config_get_int("mini_commander/cmd_line_color_bg_b=0");
 
     /* macros */
     for(i=0; i<=MAX_NUM_MACROS-1; i++)
@@ -343,26 +321,24 @@ load_session(void)
 		}
 
 	    g_snprintf(section, sizeof(section), "mini_commander/macro_pattern_%.2u=%s", i+1, default_macro_pattern);
-	    free(prop.macro_pattern[i]);
-	    prop.macro_pattern[i] = (char *)gnome_config_get_string((gchar *) section);
+	    free(prop->macro_pattern[i]);
+	    prop->macro_pattern[i] = (char *)gnome_config_get_string((gchar *) section);
 
 	    g_snprintf(section, sizeof(section), "mini_commander/macro_command_%.2u=%s", i+1, default_macro_command);
-	    free(prop.macro_command[i]);
-	    prop.macro_command[i] = (char *)gnome_config_get_string((gchar *) section);
+	    free(prop->macro_command[i]);
+	    prop->macro_command[i] = (char *)gnome_config_get_string((gchar *) section);
 
-	    if(prop.macro_pattern[i][0] != '\0')
+	    if(prop->macro_pattern[i][0] != '\0')
 		{
-		    prop.macro_regex[i] = malloc(sizeof(regex_t));
+		    prop->macro_regex[i] = malloc(sizeof(regex_t));
 		    /* currently we don't care about syntax errors in regex patterns */
-		    regcomp(prop.macro_regex[i], prop.macro_pattern[i], REG_EXTENDED);
+		    regcomp(prop->macro_regex[i], prop->macro_pattern[i], REG_EXTENDED);
 		}
 	    else
 		{
-		    prop.macro_regex[i] = NULL;
+		    prop->macro_regex[i] = NULL;
 		}
 
-	    prop_tmp.macro_pattern[i] = (char *)NULL;
-	    prop_tmp.macro_command[i] = (char *)NULL;
 
 	}    
 
@@ -378,6 +354,8 @@ load_session(void)
 	}
 
     gnome_config_pop_prefix();
+    
+    return prop;
 }
 
 
@@ -387,7 +365,7 @@ save_session(void)
 {
     int i;
     char section[100];
-
+#if 0
     /* gnome_config_push_prefix(globcfgpath); */
     /* all instances of mini-commander use the same global settings */
     gnome_config_push_prefix("/mini-commander/"); 
@@ -448,27 +426,7 @@ save_session(void)
     gnome_config_drop_all();
     
     gnome_config_pop_prefix(); 
-}
-
-gint
-save_session_signal(GtkWidget *widget, const char *privcfgpath, const char *globcfgpath)
-{       
-    if(!prop.flat_layout)
-      show_message((gchar *) _("saving prefs...")); 	    
-
-    save_session();
-
-    /* make sure you return FALSE, otherwise your applet might not
-       work compeltely, there are very few circumstances where you
-       want to return TRUE. This behaves similiar to GTK events, in
-       that if you return FALSE it means that you haven't done
-       everything yourself, meaning you want the panel to save your
-       other state such as the panel you are on, position,
-       parameter, etc ... */
-    return FALSE;
-    widget = NULL;
-    privcfgpath = NULL;
-    globcfgpath = NULL;
+#endif
 }
 
 static void
@@ -481,6 +439,106 @@ phelp_cb (GtkWidget *w, gint tab, gpointer data)
    #endif
 }
 
+static void
+check_time_toggled (GtkToggleButton *button, gpointer data)
+{
+    PanelApplet *applet = data;
+    properties *prop;
+    gboolean toggled;
+    
+    prop = g_object_get_data (G_OBJECT (applet), "prop");
+    
+    toggled = gtk_toggle_button_get_active (button);
+    
+    if (toggled == prop->show_time) 
+        return;
+        
+    prop->show_time = toggled;
+    redraw_applet (applet);
+    
+}
+
+static void
+check_date_toggled (GtkToggleButton *button, gpointer data)
+{
+    PanelApplet *applet = data;
+    properties *prop;
+    gboolean toggled;
+    
+    prop = g_object_get_data (G_OBJECT (applet), "prop");
+    
+    toggled = gtk_toggle_button_get_active (button);
+    
+    if (toggled == prop->show_date) 
+        return;
+        
+    prop->show_date = toggled;
+    redraw_applet (applet);
+    
+}
+
+static void
+check_handle_toggled (GtkToggleButton *button, gpointer data)
+{
+    PanelApplet *applet = data;
+    properties *prop;
+    gboolean toggled;
+    
+    prop = g_object_get_data (G_OBJECT (applet), "prop");
+    
+    toggled = gtk_toggle_button_get_active (button);
+    
+    if (toggled == prop->show_handle) 
+        return;
+        
+    prop->show_handle = toggled;
+    redraw_applet (applet);
+    
+}
+
+static void
+check_frame_toggled (GtkToggleButton *button, gpointer data)
+{
+    PanelApplet *applet = data;
+    properties *prop;
+    gboolean toggled;
+    
+    prop = g_object_get_data (G_OBJECT (applet), "prop");
+    
+    toggled = gtk_toggle_button_get_active (button);
+    
+    if (toggled == prop->show_frame) 
+        return;
+        
+    prop->show_frame = toggled;
+    redraw_applet (applet);
+    
+}
+
+static void
+autocomplete_toggled (GtkToggleButton *button, gpointer data)
+{
+    PanelApplet *applet = data;
+    properties *prop;
+    gboolean toggled;
+    
+    prop = g_object_get_data (G_OBJECT (applet), "prop");
+    
+    toggled = gtk_toggle_button_get_active (button);
+    
+    if (toggled == prop->auto_complete_history) 
+        return;
+        
+    prop->auto_complete_history = toggled;
+    
+}
+
+static void
+response_cb (GtkDialog *dialog, gint it, gpointer data)
+{
+    gtk_widget_hide (GTK_WIDGET (dialog));
+
+}
 
 void
 properties_box(BonoboUIComponent *uic, gpointer data, const gchar *verbname)
@@ -488,7 +546,10 @@ properties_box(BonoboUIComponent *uic, gpointer data, const gchar *verbname)
    #if 0 /* FIXME */
     static GnomeHelpMenuEntry help_entry = { NULL,  "properties" };
    #endif
+    PanelApplet *applet = data;
+    properties *prop;
     static GtkWidget *properties_box = NULL;
+    GtkWidget *notebook;
     GtkWidget *vbox, *vbox1, *frame;
     GtkWidget *hbox;
     GtkWidget *table;
@@ -500,26 +561,23 @@ properties_box(BonoboUIComponent *uic, gpointer data, const gchar *verbname)
     char text_label[50], buffer[50];
     int i;
 
-
     if (properties_box != NULL)
     {
-        gdk_window_show(GTK_WIDGET(properties_box)->window);
-	gdk_window_raise(GTK_WIDGET(properties_box)->window);
+        gtk_window_present (GTK_WINDOW (properties_box));
 	return;
     }
    #if 0 /* FIXME */
     help_entry.name = gnome_app_id;
    #endif
-
-    reset_temporary_prefs();
-
-    properties_box = gnome_property_box_new();
+    prop = g_object_get_data (G_OBJECT (applet), "prop");
+    properties_box = gtk_dialog_new_with_buttons (_("Command Line Properties"), NULL,
+						  GTK_DIALOG_DESTROY_WITH_PARENT,
+						  GTK_STOCK_CLOSE, GTK_RESPONSE_CLOSE,
+						  NULL);
     
-    gtk_window_set_title(GTK_WINDOW(properties_box), _("Mini-Commander Properties"));
-    gtk_signal_connect(GTK_OBJECT(properties_box),
-		       "destroy",
-		       gtk_widget_destroyed,
-		       &properties_box);
+    notebook = gtk_notebook_new ();
+    gtk_box_pack_start (GTK_BOX (GTK_DIALOG (properties_box)->vbox), 
+    			notebook, TRUE, TRUE, 0);
     
     /* time & date */
     vbox = gtk_vbox_new(FALSE, GNOME_PAD_BIG);
@@ -534,26 +592,16 @@ properties_box(BonoboUIComponent *uic, gpointer data, const gchar *verbname)
 
     /* show time check box */
     check_time = gtk_check_button_new_with_label (_("Show time"));
-    gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(check_time), prop.show_time);
-    gtk_signal_connect(GTK_OBJECT(check_time),
-		       "toggled",
-		       GTK_SIGNAL_FUNC(checkbox_toggled_signal),
-		       &prop_tmp.show_time);
-    gtk_signal_connect_object(GTK_OBJECT(check_time), "toggled",
-			      GTK_SIGNAL_FUNC(gnome_property_box_changed),
-			      GTK_OBJECT(properties_box));  
+    gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(check_time), prop->show_time);
+    g_signal_connect (G_OBJECT (check_time), "toggled",
+    		      G_CALLBACK (check_time_toggled), applet);
     gtk_box_pack_start(GTK_BOX(vbox1), check_time, FALSE, TRUE, 0);
 
     /* show date check box */
     check_date = gtk_check_button_new_with_label (_("Show date"));
-    gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(check_date), prop.show_date);
-    gtk_signal_connect(GTK_OBJECT(check_date),
-		       "toggled",
-		       GTK_SIGNAL_FUNC(checkbox_toggled_signal),
-		       &prop_tmp.show_date);
-    gtk_signal_connect_object(GTK_OBJECT(check_date), "toggled",
-			      GTK_SIGNAL_FUNC(gnome_property_box_changed),
-			      GTK_OBJECT(properties_box));
+    gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(check_date), prop->show_date);
+    g_signal_connect (G_OBJECT (check_date), "toggled",
+    		      G_CALLBACK (check_date_toggled), applet);
     gtk_box_pack_start(GTK_BOX(vbox1), check_date, FALSE, TRUE, 0);
 
 
@@ -567,32 +615,22 @@ properties_box(BonoboUIComponent *uic, gpointer data, const gchar *verbname)
 
     /* show handle check box */
     check_handle = gtk_check_button_new_with_label (_("Show handle"));
-    gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(check_handle), prop.show_handle);
-    gtk_signal_connect(GTK_OBJECT(check_handle),
-                       "toggled",
-                       GTK_SIGNAL_FUNC(checkbox_toggled_signal),
-                       &prop_tmp.show_handle);
-    gtk_signal_connect_object(GTK_OBJECT(check_handle), "toggled",
-                              GTK_SIGNAL_FUNC(gnome_property_box_changed),
-                              GTK_OBJECT(properties_box));
+    gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(check_handle), prop->show_handle);
+    g_signal_connect (G_OBJECT (check_handle), "toggled",
+    		      G_CALLBACK (check_handle_toggled), applet);
     gtk_box_pack_start(GTK_BOX(vbox1), check_handle, FALSE, TRUE, 0);
 
     /* show frame check box */
     check_frame = gtk_check_button_new_with_label (_("Show frame"));
-    gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(check_frame), prop.show_frame);
-    gtk_signal_connect(GTK_OBJECT(check_frame),
-                       "toggled",
-                       GTK_SIGNAL_FUNC(checkbox_toggled_signal),
-                       &prop_tmp.show_frame);
-    gtk_signal_connect_object(GTK_OBJECT(check_frame), "toggled",
-                              GTK_SIGNAL_FUNC(gnome_property_box_changed),
-                              GTK_OBJECT(properties_box));
+    gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(check_frame), prop->show_frame);
+    g_signal_connect (G_OBJECT (check_frame), "toggled",
+    		      G_CALLBACK (check_frame_toggled), applet);
     gtk_box_pack_start(GTK_BOX(vbox1), check_frame, FALSE, TRUE, 0);
 
 
 
     /* auto complete frame */
-    frame = gtk_frame_new(_("Auto Completion"));
+    frame = gtk_frame_new(_("Autocompletion"));
     gtk_box_pack_start(GTK_BOX(vbox), frame, FALSE, FALSE, 0);
 
     vbox1 = gtk_vbox_new(FALSE, GNOME_PAD_SMALL);
@@ -600,17 +638,12 @@ properties_box(BonoboUIComponent *uic, gpointer data, const gchar *verbname)
     gtk_container_add(GTK_CONTAINER(frame), vbox1);
 
     /* show history autocomplete */
-    check_auto_complete_history = gtk_check_button_new_with_label (_("Enable history based auto completion"));
-    gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(check_auto_complete_history), prop.auto_complete_history);
-    gtk_signal_connect(GTK_OBJECT(check_auto_complete_history),
-                       "toggled",
-                       GTK_SIGNAL_FUNC(checkbox_toggled_signal),
-                       &prop_tmp.auto_complete_history);
-    gtk_signal_connect_object(GTK_OBJECT(check_auto_complete_history), "toggled",
-                              GTK_SIGNAL_FUNC(gnome_property_box_changed),
-                              GTK_OBJECT(properties_box));
+    check_auto_complete_history = gtk_check_button_new_with_label (_("Enable history based autocompletion"));
+    gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(check_auto_complete_history), prop->auto_complete_history);
+    g_signal_connect (G_OBJECT (check_auto_complete_history), "toggled",
+    		      G_CALLBACK (autocomplete_toggled), applet);
     gtk_box_pack_start(GTK_BOX(vbox1), check_auto_complete_history, FALSE, TRUE, 0);
-
+#if 0
     /* Size */
     frame = gtk_frame_new(_("Size"));
     gtk_box_pack_start(GTK_BOX(vbox), frame, FALSE, FALSE, 0);
@@ -634,7 +667,7 @@ properties_box(BonoboUIComponent *uic, gpointer data, const gchar *verbname)
 		     0, 0);
     
     entry = gtk_entry_new_with_max_length(4);
-    g_snprintf(buffer, sizeof(buffer), "%d", prop.normal_size_x);
+    g_snprintf(buffer, sizeof(buffer), "%d", prop->normal_size_x);
     gtk_entry_set_text(GTK_ENTRY(entry), (gchar *) buffer);
     gtk_widget_set_usize(entry, 50, -1);
     gtk_signal_connect(GTK_OBJECT(entry),
@@ -663,7 +696,7 @@ properties_box(BonoboUIComponent *uic, gpointer data, const gchar *verbname)
 		     0, 0);
 
     entry = gtk_entry_new_with_max_length(4);
-    g_snprintf(buffer, sizeof(buffer), "%d", prop.normal_size_y);
+    g_snprintf(buffer, sizeof(buffer), "%d", prop->normal_size_y);
     gtk_entry_set_text(GTK_ENTRY(entry), (gchar *) buffer);
     gtk_widget_set_usize(entry, 50, -1);
     gtk_signal_connect(GTK_OBJECT(entry),
@@ -692,7 +725,7 @@ properties_box(BonoboUIComponent *uic, gpointer data, const gchar *verbname)
 		     0, 0);
 
     entry = gtk_entry_new_with_max_length(4);
-    g_snprintf(buffer, sizeof(buffer), "%d", prop.cmd_line_size_y);
+    g_snprintf(buffer, sizeof(buffer), "%d", prop->cmd_line_size_y);
     gtk_entry_set_text(GTK_ENTRY(entry), (gchar *) buffer);
     gtk_widget_set_usize(entry, 50, -1);
     gtk_signal_connect(GTK_OBJECT(entry),
@@ -722,7 +755,7 @@ properties_box(BonoboUIComponent *uic, gpointer data, const gchar *verbname)
 		     GTK_FILL, 0,
 		     0, 0);
     */
-
+#endif
     /* Color */
     frame = gtk_frame_new(_("Colors"));
     gtk_box_pack_start(GTK_BOX(vbox), frame, FALSE, FALSE, 0);
@@ -745,18 +778,14 @@ properties_box(BonoboUIComponent *uic, gpointer data, const gchar *verbname)
 
     color_picker = gnome_color_picker_new();
     gnome_color_picker_set_i16(GNOME_COLOR_PICKER(color_picker),
-			       prop.cmd_line_color_fg_r, 
-			       prop.cmd_line_color_fg_g, 
-			       prop.cmd_line_color_fg_b, 
+			       prop->cmd_line_color_fg_r, 
+			       prop->cmd_line_color_fg_g, 
+			       prop->cmd_line_color_fg_b, 
 			       0);
     gtk_signal_connect(GTK_OBJECT(color_picker),
 		       "color_set",
 		       GTK_SIGNAL_FUNC(color_cmd_fg_changed_signal),
-		       (gpointer *) NULL);
-    gtk_signal_connect_object(GTK_OBJECT(color_picker),
-			      "color_set",
-			      GTK_SIGNAL_FUNC(gnome_property_box_changed),
-			      GTK_OBJECT(properties_box));      
+		       applet);
     /*
       gtk_box_pack_start(GTK_BOX(hbox), color_picker, FALSE, TRUE, 0);
     */
@@ -779,18 +808,14 @@ properties_box(BonoboUIComponent *uic, gpointer data, const gchar *verbname)
 		     0, 0);
     color_picker = gnome_color_picker_new();
     gnome_color_picker_set_i16(GNOME_COLOR_PICKER(color_picker),
-			       prop.cmd_line_color_bg_r, 
-			       prop.cmd_line_color_bg_g, 
-			       prop.cmd_line_color_bg_b, 
+			       prop->cmd_line_color_bg_r, 
+			       prop->cmd_line_color_bg_g, 
+			       prop->cmd_line_color_bg_b, 
 			       0);
     gtk_signal_connect(GTK_OBJECT(color_picker),
 		       "color_set",
 		       GTK_SIGNAL_FUNC(color_cmd_bg_changed_signal),
-		       (gpointer *) NULL);
-    gtk_signal_connect_object(GTK_OBJECT(color_picker),
-			      "color_set",
-			      GTK_SIGNAL_FUNC(gnome_property_box_changed),
-			      GTK_OBJECT(properties_box));      
+		       applet);
     gtk_table_attach(GTK_TABLE(table), 
 		     color_picker,
 		     1, 2,
@@ -800,11 +825,8 @@ properties_box(BonoboUIComponent *uic, gpointer data, const gchar *verbname)
     
 
 
-    gnome_property_box_append_page(GNOME_PROPERTY_BOX(properties_box),
-				   vbox,
-				   gtk_label_new(_("General")));
-
-
+    gtk_notebook_append_page (GTK_NOTEBOOK (notebook), vbox,
+    			      gtk_label_new_with_mnemonic (_("_General")));
 
     /* Macros */   
     frame = gtk_frame_new((gchar *) NULL);
@@ -834,16 +856,14 @@ properties_box(BonoboUIComponent *uic, gpointer data, const gchar *verbname)
 	    
 	    entry = gtk_entry_new_with_max_length(MAX_MACRO_PATTERN_LENGTH);
 	    gtk_widget_set_usize(entry, 75, -1);
-	    if (prop.macro_pattern[i] != (gchar *) NULL)
-		gtk_entry_set_text(GTK_ENTRY(entry), (gchar *) prop.macro_pattern[i]);
+	    if (prop->macro_pattern[i] != (gchar *) NULL)
+		gtk_entry_set_text(GTK_ENTRY(entry), (gchar *) prop->macro_pattern[i]);
+	    #ifdef FIXME
 	    gtk_signal_connect(GTK_OBJECT(entry),
 			       "changed",
 			       GTK_SIGNAL_FUNC(entry_changed_signal),
-			       &prop_tmp.macro_pattern[i]);
-	    gtk_signal_connect_object(GTK_OBJECT(entry),
-				      "changed",
-				      GTK_SIGNAL_FUNC(gnome_property_box_changed),
-				      GTK_OBJECT(properties_box));      
+			       &prop->macro_pattern[i]);
+	    #endif
 	    gtk_box_pack_start(GTK_BOX(hbox), entry, FALSE, TRUE, 0);
 	    
 	    /* command */
@@ -851,36 +871,24 @@ properties_box(BonoboUIComponent *uic, gpointer data, const gchar *verbname)
 	    gtk_box_pack_start(GTK_BOX(hbox), gtk_label_new(text_label), FALSE, TRUE, 0);
 	    
 	    entry = gtk_entry_new_with_max_length(MAX_COMMAND_LENGTH);
-	    if (prop.macro_command[i] != (gchar *) NULL)
-		gtk_entry_set_text(GTK_ENTRY(entry), prop.macro_command[i]);
+	    if (prop->macro_command[i] != (gchar *) NULL)
+		gtk_entry_set_text(GTK_ENTRY(entry), prop->macro_command[i]);
+	    #ifdef FIXME
 	    gtk_signal_connect(GTK_OBJECT(entry),
 			       "changed",
 			       GTK_SIGNAL_FUNC(entry_changed_signal),
 			       &prop_tmp.macro_command[i]);
-	    gtk_signal_connect_object(GTK_OBJECT(entry),
-				      "changed",
-				      GTK_SIGNAL_FUNC(gnome_property_box_changed),
-				      GTK_OBJECT(properties_box));  
+	    #endif
 	    gtk_box_pack_start(GTK_BOX(hbox), entry, TRUE, TRUE, 0);
 	}
 
-    gnome_property_box_append_page(GNOME_PROPERTY_BOX(properties_box),
-				   frame,
-				   gtk_label_new((gchar *) _("Macros")));
-
-    gtk_signal_connect(GTK_OBJECT(properties_box), 
-		       "apply",
-		       GTK_SIGNAL_FUNC(properties_box_apply_signal),
-		       NULL);
-
-   #if 0 /* FIXME */
-    gtk_signal_connect(GTK_OBJECT(properties_box),
-		       "help",
-		       GTK_SIGNAL_FUNC(phelp_cb),
-		       &help_entry);
-   #endif
+    gtk_notebook_append_page (GTK_NOTEBOOK (notebook), frame,
+    			      gtk_label_new_with_mnemonic (_("_Macros")));
     
     gtk_widget_show_all(properties_box);
+    
+    g_signal_connect (G_OBJECT (properties_box), "response",
+    		      G_CALLBACK (response_cb), properties_box);
     return;
 }
 
